@@ -1,21 +1,6 @@
-allmetap <- function(p, method = NULL, log.p = FALSE) {
+allmetap <- function(p, method = "all", log.p = FALSE) {
    if(is.null(method)) stop("Must specify a method")
-mydata <-
-  '"funcs","eponyms"
-   "logitp",
-   "maximump",
-   "meanp",
-   "meanz",
-   "minimump","Tippett"
-   "sumlog","Fisher"
-   "sump","Edgington"
-   "sumz","Stouffer"
-'
-   con <- textConnection(mydata)
-   details <- read.csv(con, stringsAsFactors = FALSE)
-   row.names(details) <- c("logitp", "maximump", "meanp", "meanz",
-      "minimump", "sumlog", "sump", "sumz")
-   close(con)
+# note that details is in sysdata.rda now
 # now which have log.p as parameter
 logpfuncs <- c("logitp", "meanz", "sumlog", "sumz")
 # if all specified reset funcnames
@@ -51,10 +36,12 @@ helper <- function(x) {
       eponym[i] <- details[row.names(res[i,]),"eponyms"]
    }
    res$eponym <- eponym
+   attr(res, "logp") <- log.p
    class(res) <- c("allmetap", "data.frame")
    res
 }
 print.allmetap <- function(x, digits = 5, ...) {
    print(format(x, digits = digits, ...), ...)
+   if(attr(x, "logp")) print("P-values are on natural log scale")
    invisible(x)
 }
